@@ -1,10 +1,22 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 /*
- * -- SuperLU routine (version 3.0) --
+ * -- SuperLU routine (version 5.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * October 15, 2003
  *
+ * Last update: July 10, 2015
+ *
  */
 #include "slu_cdefs.h"
 
@@ -31,12 +43,14 @@ int main(int argc, char *argv[])
     NCformat       *Astore;
     NCformat       *Ustore;
     SCformat       *Lstore;
+    GlobalLU_t	   Glu; /* facilitate multiple factorizations with 
+                           SamePattern_SameRowPerm                  */
     complex         *a, *a1;
     int            *asub, *xa, *asub1, *xa1;
     int            *perm_r; /* row permutations from partial pivoting */
     int            *perm_c; /* column permutation vector */
     int            *etree;
-    void           *work;
+    void           *work = NULL;
     int            info, lwork, nrhs, ldx;
     int            i, j, m, n, nnz;
     complex         *rhsb, *rhsb1, *rhsx, *xact;
@@ -46,6 +60,8 @@ int main(int argc, char *argv[])
     mem_usage_t    mem_usage;
     superlu_options_t options;
     SuperLUStat_t stat;
+    FILE 	   *fp = stdin;
+
     extern void    parse_command_line();
 
 #if ( DEBUGlevel>=1 )
@@ -87,7 +103,7 @@ int main(int argc, char *argv[])
     }
 
     /* Read matrix A from a file in Harwell-Boeing format.*/
-    creadhb(&m, &n, &nnz, &a, &asub, &xa);
+    creadhb(fp, &m, &n, &nnz, &a, &asub, &xa);
     if ( !(a1 = complexMalloc(nnz)) ) ABORT("Malloc fails for a1[].");
     if ( !(asub1 = intMalloc(nnz)) ) ABORT("Malloc fails for asub1[].");
     if ( !(xa1 = intMalloc(n+1)) ) ABORT("Malloc fails for xa1[].");
@@ -133,7 +149,7 @@ int main(int argc, char *argv[])
        ------------------------------------------------------------*/
     cgssvx(&options, &A, perm_c, perm_r, etree, equed, R, C,
            &L, &U, work, lwork, &B, &X, &rpg, &rcond, ferr, berr,
-           &mem_usage, &stat, &info);
+           &Glu, &mem_usage, &stat, &info);
 
     printf("First system: cgssvx() returns info %d\n", info);
 
@@ -188,7 +204,7 @@ int main(int argc, char *argv[])
 
     cgssvx(&options, &A1, perm_c, perm_r, etree, equed, R, C,
            &L, &U, work, lwork, &B1, &X, &rpg, &rcond, ferr, berr,
-           &mem_usage, &stat, &info);
+           &Glu, &mem_usage, &stat, &info);
 
     printf("\nSecond system: cgssvx() returns info %d\n", info);
 
