@@ -66,7 +66,7 @@ int main(int argc, char *argv[])
     float         *ferr, *berr;
     float         *rwork;
     float	   *wwork;
-    void           *work;
+    void           *work = NULL;
     int            info, lwork, nrhs, panel_size, relax;
     int            m, n, nnz;
     float         *xact;
@@ -83,7 +83,7 @@ int main(int argc, char *argv[])
     int            zerot, izero, ioff;
     double         u;
     float         anorm, cndnum;
-    float         *Afull;
+    float         *Afull = NULL;
     float         result[NTESTS];
     superlu_options_t options;
     fact_t         fact;
